@@ -1,5 +1,5 @@
 package Crypt::Passphrase;
-$Crypt::Passphrase::VERSION = '0.002';
+$Crypt::Passphrase::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -70,7 +70,7 @@ sub new {
 
 sub _normalize_password {
 	my $password = shift;
-	return encode(NFC($password), 'utf-8-strict');
+	return encode('utf-8-strict', NFC($password));
 }
 
 sub hash_password {
@@ -112,7 +112,7 @@ Crypt::Passphrase - A module for managing passwords in a cryptographically agile
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
